import { __decorate, __extends } from 'tslib';
import { defineInjectable, Injectable, inject } from '@angular/core';
import { NgbDateNativeAdapter, NgbDateParserFormatter, NgbDatepickerI18n } from '@ng-bootstrap/ng-bootstrap';
import { isNumber } from 'util';

var I18nEsService = /** @class */ (function () {
    function I18nEsService() {
        this.language = "es";
    }
    I18nEsService.ngInjectableDef = defineInjectable({ factory: function I18nEsService_Factory() { return new I18nEsService(); }, token: I18nEsService, providedIn: "root" });
    I18nEsService = __decorate([
        Injectable({
            providedIn: "root"
        })
    ], I18nEsService);
    return I18nEsService;
}());

function padNumber(value) {
    if (isNumber(value)) {
        return ("0" + value).slice(-2);
    }
    else {
        return '';
    }
}
function toInteger(value) {
    return parseInt("" + value, 10);
}
var DateAdapter = /** @class */ (function (_super) {
    __extends(DateAdapter, _super);
    function DateAdapter() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DateAdapter.prototype.fromModel = function (date) {
        if (typeof date === "string") {
            date = new Date(date);
        }
        return date && date.getFullYear
            ? {
                year: date.getFullYear(),
                month: date.getMonth() + 1,
                day: date.getDate()
            }
            : null;
    };
    return DateAdapter;
}(NgbDateNativeAdapter));
var EsDateFormat = /** @class */ (function (_super) {
    __extends(EsDateFormat, _super);
    function EsDateFormat() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    EsDateFormat.prototype.parse = function (value) {
        if (value) {
            var dateParts = value.trim().split("/");
            if (dateParts.length === 1 && isNumber(dateParts[0])) {
                return { day: toInteger(dateParts[0]), month: null, year: null };
            }
            else if (dateParts.length === 2 &&
                isNumber(dateParts[0]) &&
                isNumber(dateParts[1])) {
                return {
                    day: toInteger(dateParts[0]),
                    month: toInteger(dateParts[1]),
                    year: null
                };
            }
            else if (dateParts.length === 3 &&
                isNumber(dateParts[0]) &&
                isNumber(dateParts[1]) &&
                isNumber(dateParts[2])) {
                return {
                    day: toInteger(dateParts[0]),
                    month: toInteger(dateParts[1]),
                    year: toInteger(dateParts[2])
                };
            }
        }
        return null;
    };
    EsDateFormat.prototype.format = function (date) {
        return date
            ? (isNumber(date.day) ? padNumber(date.day) : "") +
                "/" +
                (isNumber(date.month) ? padNumber(date.month) : "") +
                "/" +
                (isNumber(date.year) ? date.year : "")
            : "";
    };
    return EsDateFormat;
}(NgbDateParserFormatter));
var I18N_VALUES = {
    es: {
        weekdays: ["Lu", "Ma", "Mi", "Ju", "Vi", "Sa", "Do"],
        months: [
            "Ene",
            "Feb",
            "Mar",
            "Abr",
            "May",
            "Jun",
            "Jul",
            "Ago",
            "Sep",
            "Oct",
            "Nov",
            "Dic"
        ],
        dayNames: [
            "Lunes",
            "Martes",
            "Miércoles",
            "Jueves",
            "Viernes",
            "Sábado",
            "Domingo"
        ],
        monthNames: [
            "Enero",
            "Febrero",
            "Marzo",
            "Abril",
            "Mayo",
            "Junio",
            "Julio",
            "Agosto",
            "Septiembre",
            "Octubre",
            "Noviembre",
            "Diciembre"
        ]
    }
};

// Define custom service providing the months and weekdays translations
var DatepickerI18nService = /** @class */ (function (_super) {
    __extends(DatepickerI18nService, _super);
    function DatepickerI18nService(_i18n) {
        var _this = _super.call(this) || this;
        _this._i18n = _i18n;
        return _this;
    }
    DatepickerI18nService.prototype.getWeekdayShortName = function (weekday) {
        return I18N_VALUES[this._i18n.language].weekdays[weekday - 1];
    };
    DatepickerI18nService.prototype.getMonthShortName = function (month) {
        return I18N_VALUES[this._i18n.language].months[month - 1];
    };
    DatepickerI18nService.prototype.getMonthFullName = function (month) {
        return I18N_VALUES[this._i18n.language].monthNames[month - 1];
    };
    DatepickerI18nService.prototype.getDayAriaLabel = function (date) {
        return date.day + "/" + date.month + "/" + date.year;
    };
    DatepickerI18nService.ctorParameters = function () { return [
        { type: I18nEsService }
    ]; };
    DatepickerI18nService.ngInjectableDef = defineInjectable({ factory: function DatepickerI18nService_Factory() { return new DatepickerI18nService(inject(I18nEsService)); }, token: DatepickerI18nService, providedIn: "root" });
    DatepickerI18nService = __decorate([
        Injectable({
            providedIn: "root"
        })
    ], DatepickerI18nService);
    return DatepickerI18nService;
}(NgbDatepickerI18n));

/**
 * Generated bundle index. Do not edit.
 */

export { DateAdapter, DatepickerI18nService, EsDateFormat, I18N_VALUES, I18nEsService, padNumber, toInteger };
//# sourceMappingURL=ng-bootstrap-ar.js.map
